@@ -21,17 +21,17 @@ build_time_vars = {'ABIFLAGS': 'd',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
-           '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
-           '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
-           '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g -grecord-gcc-switches '
-           '-pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1  '
+           '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
            '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv    '
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
+           '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
+           '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
            '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
@@ -41,13 +41,13 @@ build_time_vars = {'ABIFLAGS': 'd',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+ 'CONFIGURE_CFLAGS': '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                      '-m64 -mcpu=power9 -mtune=power9 '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-D_GNU_SOURCE -fPIC -fwrapv',
- 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -90,7 +90,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                 "'--with-builtin-hashlib-hashes=blake2' '--with-valgrind' "
                 "'--without-ensurepip' '--with-pydebug' "
                 "'build_alias=ppc64le-redhat-linux-gnu' "
-                "'host_alias=ppc64le-redhat-linux-gnu' 'CC=gcc' 'CFLAGS=   "
+                "'host_alias=ppc64le-redhat-linux-gnu' 'CC=gcc' 'CFLAGS= -O2  "
                 '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                 '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   -m64 '
@@ -657,7 +657,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
         '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
         '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
         '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
@@ -696,28 +696,29 @@ build_time_vars = {'ABIFLAGS': 'd',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions '
-                             '-g -grecord-gcc-switches -pipe -Wall '
+                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  '
+                             '-fexceptions -g -grecord-gcc-switches -pipe '
+                             '-Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wp,-D_GLIBCXX_ASSERTIONS  '
+                             '-fstack-protector-strong   -m64 -mcpu=power9 '
+                             '-mtune=power9 -fasynchronous-unwind-tables '
+                             '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
+                             '-fwrapv -O2  -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -mcpu=power9 '
                              '-mtune=power9 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -fexceptions -g -grecord-gcc-switches '
-                             '-pipe -Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv  -O2  -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   -m64 -mcpu=power9 '
                              '-mtune=power9 -fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv    -fexceptions -g -grecord-gcc-switches '
-                             '-pipe -Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
-                             '-Wp,-D_GLIBCXX_ASSERTIONS  '
-                             '-fstack-protector-strong   -m64 -mcpu=power9 '
-                             '-mtune=power9 -fasynchronous-unwind-tables '
-                             '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -O0 -Wno-cpp -flto=auto '
+                             '-fwrapv  -O0 -Wno-cpp -O2 -flto=auto '
                              '-ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -734,10 +735,10 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
-                             '-fexceptions -g -grecord-gcc-switches -pipe '
-                             '-Wall -Werror=format-security '
-                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fvisibility=hidden -O2 -flto=auto '
+                             '-ffat-lto-objects -fexceptions -g '
+                             '-grecord-gcc-switches -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
@@ -745,29 +746,30 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-m64 -mcpu=power9 -mtune=power9 '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -fno-semantic-interposition -O0 -Wno-cpp '
+                             '-fwrapv -fno-semantic-interposition -O0 '
+                             '-Wno-cpp  '
                              '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
                              '-I/builddir/build/BUILD/Python-3.9.19/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
               '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp',
- 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
+ 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -781,7 +783,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-Wextra -Wno-unused-result -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -790,26 +792,26 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                      '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
                      '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                     '-fno-semantic-interposition -O0 -Wno-cpp '
+                     '-fno-semantic-interposition -O0 -Wno-cpp  '
                      '-I/builddir/build/BUILD/Python-3.9.19/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
                    '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+                   '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
                    '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+                   '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
                    '-fstack-protector-strong   -m64 -mcpu=power9 -mtune=power9 '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp -flto=auto '
+                   '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp -O2 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
@@ -823,7 +825,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -831,7 +833,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
                    '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
                    '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
-                   '-fno-semantic-interposition -O0 -Wno-cpp '
+                   '-fno-semantic-interposition -O0 -Wno-cpp  '
                    '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.9.19/Include -fPIC '
@@ -865,26 +867,26 @@ build_time_vars = {'ABIFLAGS': 'd',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1    -fexceptions -g '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -mcpu=power9 -mtune=power9 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -mcpu=power9 -mtune=power9 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-m64 -mcpu=power9 -mtune=power9 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp -flto=auto '
-                        '-ffat-lto-objects -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -Wno-cpp -O2 '
+                        '-flto=auto -ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -899,7 +901,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -909,7 +911,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-mcpu=power9 -mtune=power9 '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-D_GNU_SOURCE -fPIC -fwrapv '
-                        '-fno-semantic-interposition -O0 -Wno-cpp '
+                        '-fno-semantic-interposition -O0 -Wno-cpp  '
                         '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
                         '-I/builddir/build/BUILD/Python-3.9.19/Include -fPIC',
